![CogniChem Logo](https://cognichem.com/images/cc-logo-color.svg)
# CogniChem Python Client

[![GitHub version](https://badge.fury.io/gh/cognitive-chemistry-labs%2Fcognichem-client-python.svg)](https://badge.fury.io/gh/ecrl%2Fcognichem-client-python)
[![PyPI version](https://badge.fury.io/py/cognichem-client.svg)](https://badge.fury.io/py/cognichem-client)
[![GitHub license](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/Cognitive-Chemistry-Labs/cognichem-client-python/blob/main/LICENSE)

## Installation

### From PyPI

```
$ pip install cognichem-client
```

### From source

```
$ git clone https://github.com/cognitive-chemistry-labs/cognichem-client-python
$ cd cognichem-client-python
$ pip install .
```

## Usage

View our [example](examples/) notebooks for more information.
